from distutils.core import setup

setup(
    name    = 'test_module',
    version = '1.1.0',
    py_modules  = ['test_module'],
    author  = 'st94',
    author_email    = 'stsewang.17@gmail.com',
    url     = 'http://www.testingst123.com',
    description = 'A simple printer of nested lists',
)
